Changelog
=========

0.2.1 (2018-11-19)
++++++++++++++++++

- First release.

0.2.0 (2018-10)
+++++++++++++++

- Parser re-write based largely on svg.path (https://github.com/regebro/svg.path/blob/master/src/svg/path/parser.py)
- 2D coordinates are now encoded as complex numbers.

0.1.0 (2016-04-10)
++++++++++++++++++

- Sharing
